def argparse(text):
	"""
	Parses all the arguments of the text that you pass in the first argument and returns a list with your arguments separated
	"""
	sho = False
	args = []
	e = []
	temparg = ""
	for i in text:
		if sho:
			if i == '"' or i == "'":
				sho = False
				args.append(temparg)
			if sho:
				temparg = temparg+i

		if not sho:
			temparg = ""
			if i == '"' or i == "'":
				sho = True
		
	for i in args:
		if i != ' ':
			e.append(i)
	return e


import requests
def checkInternet():
	"""
	Checks if you have internet, if yes, returns True, otherwise, it returns False
	"""
	try:
		requests.get("https://google.com")
		eplo = True
	except requests.exceptions.ConnectionError:
		eplo = False
	return eplo


"""
drutils.

My Multi Use Python Package
"""

__version__ = "0.1.7"
__author__ = "danilacasito"
__credits__ = "Only me, i'm the only who maintains this"
import danilacasito_drutils.parse
import danilacasito_drutils.network